@@ -24,63 +24,38 @@ use Symfony\Contracts\HttpClient\HttpClientInterface;
  *
  * @experimental
  */
-final class Hub implements HubInterface
+final class Hub implements RemoteHubInterface
 {
-    private $url;
-    private $jwtProvider;
-    private $jwtFactory;
-    private $publicUrl;
-    private $httpClient;
-
     public function __construct(
-        string $url,
-        TokenProviderInterface $jwtProvider,
-        TokenFactoryInterface $jwtFactory = null,
-        string $publicUrl = null,
-        HttpClientInterface $httpClient = null
+        private readonly string $url,
+        private readonly TokenProviderInterface $jwtProvider,
+        private readonly ?TokenFactoryInterface $jwtFactory = null,
+        private readonly ?string $publicUrl = null,
+        private ?HttpClientInterface $httpClient = null,
     ) {
-        $this->url = $url;
-        $this->jwtProvider = $jwtProvider;
-        $this->publicUrl = $publicUrl;
-        $this->jwtFactory = $jwtFactory;
         $this->httpClient = $httpClient ?? HttpClient::create();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public function getUrl(): string
     {
         return $this->url;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public function getPublicUrl(): string
     {
         return $this->publicUrl ?? $this->getUrl();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public function getProvider(): TokenProviderInterface
     {
         return $this->jwtProvider;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public function getFactory(): ?TokenFactoryInterface
     {
         return $this->jwtFactory;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public function publish(Update $update): string
     {
         $postData = [
